@@ -8,17 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_events._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@renovosolutions/cdk-library-one-time-event",
-    "1.0.235",
+    "2.0.20",
     __name__[0:-6],
-    "cdk-library-one-time-event@1.0.235.jsii.tgz",
+    "cdk-library-one-time-event@2.0.20.jsii.tgz",
 )
 
 __all__ = [
